<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANsILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * aulas_valle_Format_renderer
 *
 * @package    aulas_valle_Format
 * @author     aulas_valle
 * @copyright  aulas_valle
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

require_once($CFG->dirroot.'/course/format/topics/renderer.php');

/**
 * format_aulas_valle_renderer
 *
 * @package    format_aulas_valle
 * @author     Rodrigo Brandão (rodrigobrandao.com.br)
 * @copyright  2017 Rodrigo Brandão
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class format_aulas_valle_renderer extends format_topics_renderer{
   
    /**
     * get_button_section
     *
     * @param stdclass $course
     * @param string $name
     * @return string
     */
    protected function get_color_config($course, $name)
    {
        $return = false;
        if (isset($course->{$name})) {
            $color = str_replace('#', '', $course->{$name});
            $color = substr($color, 0, 6);
            if (preg_match('/^#?[a-f0-9]{6}$/i', $color)) {
                $return = '#'.$color;
            }
        }
        return $return;
    }

    /**
     * get_button_section
     *
     * @param stdclass $course
     * @param string $sectionvisible
     * @return string
     */
    protected function get_button_section($course, $sectionvisible)
    {
        global $PAGE;
        global $DB;
        global $CFG;
        global $USER;
        $context = context_course::instance($course->id);
        $html = '';
        $videocontainerhtml='';
        $videocontainerhtml1='';
        $videocontainerhtml2='';
        $videocontainerhtml3='';
        $videocontainerhtml4='';
        $modulevideohtml = '';
        $modulevideohtml1 = '';
        $modulevideohtml2 = '';
        $modulevideohtml3 = '';
        $modulevideohtml4 = '';
        $cardscontainerhtml= '';
        $modulecardhtml = '';
        $backnavhtml= '';
        $containerModule='';
        $containerModuleInternal='';
        $css = '';
        $container_home= '';
        $button_program_course= '';
        $button_proccess= '';
        $button_Forum= '';
        $button_meeting= '';
        $button_Doubts= '';
        $module = -1;
        $modules = -1;
        $sectionstyle = '';
        if ($colorcurrent = $this->get_color_config($course, 'colorcurrent')) {
            $css .=
            '#aulas_valle-container-section .aulas_valle-button-section.current {
                background: ' . $colorcurrent . ';
            }
            ';
        }
        if ($colorvisible = $this->get_color_config($course, 'colorvisible')) {
            $css .=
            '#aulas_valle-container-section .buttonsection.sectionvisible {
                background: ' . $colorvisible . ';
            }
            ';
        }
        if ($css) {
            $html .= html_writer::tag('style', $css);
        }
        $withoutdivisor = true;
        for ($k = 1; $k <= 6; $k++) {
            if ($course->{'moduleimg' . $k}) {
                $withoutdivisor = false;
            }
        }
        if ($withoutdivisor) {
            $course->divisor1 = 999;
        }
        $imgtabs = 0;
        $divisorshow = false;
        $count = 1;
        $count1 = 1;
        $count2 = 1;
        $count3 = 1;
        $sec= 1;
        $currentdivisor = 1;
        $currentdivisor1 = 1;
        $currentdivisor2 = 1;
        $divisorvideos = 1;
        $modinfo = get_fast_modinfo($course);
        $inline = '';



        $container_home .= html_writer::start_tag('div',['class'=>'container-fluid','id' => 'aulas_valle-modules-container']);
        $container_home .= html_writer::start_tag('div',['class'=>'row featurette']);

        /** Modules title */
        // $container_home .= html_writer::start_tag('div');

        // $container_home .= html_writer::tag('h5','Módulos',['class' => "aulas_valle-title-modules",]);
        // $container_home .= html_writer::tag('p','En esta sección podrás encontrar los módulos ligados a tu guía',['class' => "aulas_valle-subtitle-module",]);

        // $container_home .= html_writer::end_tag('div');

        /* cards */
        $cardscontainerhtml .= html_writer::start_tag('div', ['class' => "col-md-12 aulas_valle-container-cards",'style' => "margin:1rem 0;display:flex"]);
        
        // $percent = progress_percentage_aulas_valle($course->id);

        $roleid = $DB->get_field('role', 'id', ['shortname' => 'editingteacher']);
        $iseditingteacheranywhere = $DB->record_exists('role_assignments', ['userid' => $USER->id, 'roleid' => $roleid]);

        $roleidteacher = $DB->get_field('role', 'id', ['shortname' => 'teacher']);
        $isteacheranywhere = $DB->record_exists('role_assignments', ['userid' => $USER->id, 'roleid' => $roleidteacher]);

        /** creacion de las tabs */
        $cardscontainerhtml .= html_writer::start_tag('nav');
        $cardscontainerhtml .= html_writer::start_tag('div',['class'=>'nav nav-tabs aulas-valle-nav-tabs','role'=>'tablist', 'id'=> 'nav-tab']);
        for($tabs = 0; $tabs <= $course->numtabs; $tabs++){

            $counterTabs= $tabs+1;
            // $tabsname = 'tabs'.$counterTabs;
            // var_dump($tabsname);
            
            if($tabs == 0){
                $moduleName = 'Bienvenidos';
                $tabsname = 'tabs'.$counterTabs;
            }
            else{
               $tabsname = 'tabs'.$counterTabs;
               $moduleName = 'M'.$tabs;
            }
            /**tabs */
            
            if($tabs == 0){
            $cardscontainerhtml .= html_writer::start_tag('a',['class'=>'nav-item nav-link active','role'=>'tab', 'id'=> 'nav-'.$tabs.'-tab', 'href'=>"#nav-".$moduleName,"data-toggle"=>"tab"]);
            }
            else{
                $cardscontainerhtml .= html_writer::start_tag('a',['class'=>'nav-item nav-link','role'=>'tab', 'id'=> 'nav-'.$tabs.'-tab', 'href'=>"#nav-".$moduleName,"data-toggle"=>"tab"]);
            }
            $cardscontainerhtml .= $course->$tabsname;
            $cardscontainerhtml .= html_writer::end_tag('a');
            
            

            
        }
        $cardscontainerhtml .= html_writer::end_tag('div');
        $cardscontainerhtml .= html_writer::end_tag('nav');

        /** contenido de las tabs */
        $cardscontainerhtml .= html_writer::start_tag('div',['class'=>'tab-content','id'=> 'aulas_valle_nav-tabContent']);

        $count_sections = count($modinfo->get_section_info_all());
        /**divido las secciones segun el total de pestañas */
        
        $countabs= 0;
        /**cotador que dice cuantas pestañas existen */
        

        for($tabs = 0; $tabs <= $course->numtabs; $tabs++){
            $nameTab = (string)$course->{'MainObjective' . ($currentdivisor)};
            if($tabs == 0){
                $moduleName = 'Bienvenidos';
            }
            else{
               $moduleName = 'M'.$tabs;
            }

            if($tabs == 0){
            $cardscontainerhtml .= html_writer::start_tag('div',['class'=>'tab-pane fade show active','role'=>'tabpanel', 'id'=> 'nav-'.$moduleName, 'tabindex'=>'0']);
            $cardscontainerhtml .= html_writer::start_tag('div',['class'=>'d-flex flex-wrap']);

            $modulecardhtml .= html_writer::start_tag('div', ['class' => "w-100 container-fluid p-0",'style'=>'', 'id'=>'']);

            $tabsEquival = 3425;
            $str =  strval($tabs+1);
                    try {
                        $courseimage = '';
                        $fs = get_file_storage();
                        $files1 = $fs->get_area_files($context->id, 'format_aulas_valle', 'images', $tabsEquival);
                        if ($files1) {  
                            foreach ($files1 as $file1) {
                            $isimage = $file1->is_valid_image();
                                if ($isimage) {
                                    $courseimage = moodle_url::make_pluginfile_url(
                                        $file1->get_contextid(),
                                        $file1->get_component(),
                                        $file1->get_filearea(),
                                        $tabsEquival,
                                        $file1->get_filepath(),
                                        $file1->get_filename(),
                                        false
                                    );

                                    $modulecardhtml .=html_writer::empty_tag('img', array('src' => $courseimage,'alt'=>$course->{'alt_text'.$str},'id'=>'module-image-bienvenidos', 'class'=>'w-100'));
                                }
                                else{
                                    //no hacer nada
                                }
                            }
                        }
                    } catch (Exception $th) {
                        echo ' error en la prueba de robin', $th->getMessage();
                    }

                    /**
                     * 
                     * Print editor content
                     *  
                     */
                    $modulecardhtml .= html_writer::start_tag('div',['class' => "row"]);
                    try {
                        $idCourse = (int)$course->id;
                        $nameeditor = 'editor_tabs'.$str;
                        $valueFile = $DB->get_record_sql("SELECT value FROM mdl_course_format_options  where name='$nameeditor' and courseid=$idCourse");
                        $editorcontent = '';
                        
                        $modulecardhtml .= html_writer::start_tag('div',['class' => "col-sm-6 justify-text", 'style'=>"margin-bottom: 2rem;"]);
                        // $modulecardhtml .=html_writer::tag('p', $valueFile->value,['id'=>'module-editor-bienvenidos']);
                        $modulecardhtml .= $valueFile->value;
                        $modulecardhtml .= html_writer::end_tag('div');
                                
                    } catch (Exception $th) {
                        echo ' error en el editor de bienvenidos', $th->getMessage();
                    }

                    /**
                     * 
                     * Print video tabs
                     * 
                     */
                    
                    $videocontainerhtml .= html_writer::start_tag('div',['class' => "col-sm-6", 'style'=>"margin-bottom: 2rem;"]);
        
                    if(empty($course->{'tabsVideo'.$str}) || $course->{'tabsVideo'.$str} == ' '){
                        $modulevideohtml .= html_writer::start_tag('div', ['style'=>'display:none']);
                        $modulevideohtml .= html_writer::end_tag('div');
                    }
                    else{
                    $modulevideohtml .= html_writer::start_tag('div',['class' => 'video-tabs']);
                    if (strpos($course->{'tabsVideo'.$str}, 'youtube') !== false) {
                        $modulevideohtml .= html_writer::start_tag('iframe',['src'=>"https://www.youtube-nocookie.com/embed/".substr($course->{'tabsVideo'.$str},32,11)."?rel=0&showinfo=0&modestbranding=1", 'frameborder'=>'0','allow'=>'autoplay; encrypted-media','allowfullscreen'=>'true','webkitallowfullscreen'=>'true','id'=>'video-tabs-1', 'title'=>'video presentacion pestaña '.$course->$tabsname]);
                        $modulevideohtml .= html_writer::end_tag('iframe');
                    }else{
                        $modulevideohtml .= html_writer::start_tag('iframe',['src'=>"http://tumlab.local:8082/embed?m=".substr($course->{'tabsVideo'.$str},32)."", 'id'=>'video-tabs-1', 'title'=>'video presentacion pestaña '.$course->$tabsname]);
                        $modulevideohtml .= html_writer::end_tag('iframe');
                    }
                    $modulevideohtml .= html_writer::end_tag('div');
                    }
                    $videocontainerhtml  .= $modulevideohtml;
                    $videocontainerhtml .= html_writer::end_tag('div');

                    $modulecardhtml .= $videocontainerhtml;

                    $modulecardhtml .= html_writer::end_tag('div');

                    /**
                     * 
                     * Imagen de la metafora
                     * 
                     */
                    $modulecardhtml .= html_writer::start_tag('div',['class' => 'col-sm-12']);

                    $modulecardhtml .= html_writer::start_tag('div',['class' => 'col-sm-12', 'style'=>'position:relative']);

                    $tabsEquival = 13521;
                    try {
                        $courseimage = '';
                        $fs = get_file_storage();
                        $files1 = $fs->get_area_files($context->id, 'format_aulas_valle', 'images', $tabsEquival);
                        if ($files1) {  
                            foreach ($files1 as $file1) {
                            $isimage = $file1->is_valid_image();
                                if ($isimage) {
                                    $courseimage = moodle_url::make_pluginfile_url(
                                        $file1->get_contextid(),
                                        $file1->get_component(),
                                        $file1->get_filearea(),
                                        $tabsEquival,
                                        $file1->get_filepath(),
                                        $file1->get_filename(),
                                        false
                                    );

                                    $modulecardhtml .=html_writer::empty_tag('img', array('src' => $courseimage,'alt'=>$course->{'alt_metaf'},'id'=>'', 'class'=>'w-100'));
                                }
                                else{
                                    //no hacer nada
                                }
                            }
                        }
                    } catch (Exception $th) {
                        echo ' error en la prueba de robin', $th->getMessage();
                    }


                $modulecardhtml .= html_writer::end_tag('div');

                /**
                 * Modales de la metafora
                 */
                $modulecardhtml .= html_writer::start_tag('div',['class'=>'modal-btn-container']);
                
                 for($totaltabs=1; $totaltabs <= $course->numtabs; $totaltabs++ ){

                    // Button trigger modal 
                    $modulecardhtml .= html_writer::start_tag('a',['class'=>'btn btn-modal-display','data-toggle'=>'modal','data-target'=>'#exampleModal'.$totaltabs]);
                    // $modulecardhtml .= 'modal'.$totaltabs;
                    $modulecardhtml .= html_writer::end_tag('a');

                 }
                 for($totalmodals=1; $totalmodals <= $course->numtabs; $totalmodals++ ){
                    //venanas modales
                    $modulecardhtml .= html_writer::start_tag('div', ['class'=>'modal fade','id'=>'exampleModal'.$totalmodals, 'tabindex'=>'-1', 'aria-hidden'=>'true']);
                    $modulecardhtml .= html_writer::start_tag('div', ['class'=>'modal-dialog modal-dialog-centered']);
                    //modal content
                    $modulecardhtml .= html_writer::start_tag('div', ['class'=>'modal-content']);
                    $modulecardhtml .= html_writer::start_tag('div',['class'=>'modal-body p-0']);
                    //se imprimen las imagenes de los modales
                    $tabsEquival = 135201 + $totalmodals;
                    try {
                        $courseimage = '';
                        $fs = get_file_storage();
                        $files1 = $fs->get_area_files($context->id, 'format_aulas_valle', 'images', $tabsEquival);
                        if ($files1) {  
                            foreach ($files1 as $file1) {
                            $isimage = $file1->is_valid_image();
                                if ($isimage) {
                                    $courseimage = moodle_url::make_pluginfile_url(
                                        $file1->get_contextid(),
                                        $file1->get_component(),
                                        $file1->get_filearea(),
                                        $tabsEquival,
                                        $file1->get_filepath(),
                                        $file1->get_filename(),
                                        false
                                    );

                                    $modulecardhtml .=html_writer::empty_tag('img', array('src' => $courseimage,'alt'=>$course->{'alt_metaf'},'id'=>'', 'class'=>'w-100'));
                                }
                                else{
                                    //no hacer nada
                                }
                            }
                        }
                    } catch (Exception $th) {
                        echo ' error en la prueba de robin', $th->getMessage();
                    }
                    $modulecardhtml .= html_writer::end_tag('div');
                    $modulecardhtml .= html_writer::end_tag('div');
                    $modulecardhtml .= html_writer::end_tag('div');
                    $modulecardhtml .= html_writer::end_tag('div');
                 }
                $modulecardhtml .= html_writer::end_tag('div');
                 

                 //fin de los botones
                $modulecardhtml .= html_writer::end_tag('div');

                //fin de la metafora

                $modulecardhtml .= html_writer::end_tag('div');
                $modulecardhtml .= html_writer::end_tag('div');

                $cardscontainerhtml  .= $modulecardhtml;
                $modulecardhtml = '';
            }
            else if($tabs == 1){
                $cardscontainerhtml .= html_writer::start_tag('div',['class'=>'tab-pane fade ','role'=>'tabpanel', 'id'=> 'nav-'.$moduleName, 'tabindex'=>'0']);

                $cardscontainerhtml .= html_writer::start_tag('div',['class'=>'d-flex flex-wrap']);

                $modulecardhtml .= html_writer::start_tag('div', ['class' => "w-100 container-fluid p-0",'style'=>'', 'id'=>'']);

                $tabsEquival = 3426;
                $str =  strval($tabs+1);
                        try {
                            $courseimage = '';
                            $fs = get_file_storage();
                            $files1 = $fs->get_area_files($context->id, 'format_aulas_valle', 'images', $tabsEquival);
                            if ($files1) {  
                                foreach ($files1 as $file1) {
                                $isimage = $file1->is_valid_image();
                                    if ($isimage) {
                                        $courseimage = moodle_url::make_pluginfile_url(
                                            $file1->get_contextid(),
                                            $file1->get_component(),
                                            $file1->get_filearea(),
                                            $tabsEquival,
                                            $file1->get_filepath(),
                                            $file1->get_filename(),
                                            false
                                        );
    
                                        $modulecardhtml .=html_writer::empty_tag('img', array('src' => $courseimage,'alt'=>$course->{'alt_text'.$str},'id'=>'module-image-bienvenidos', 'class'=>'w-100'));
                                    }
                                    else{
                                        //no hacer nada
                                    }
                                }
                            }
                        } catch (Exception $th) {
                            echo ' error en la prueba de robin', $th->getMessage();
                        }

                        $modulecardhtml .= html_writer::start_tag('div',['class' => "row"]);
                        /**
                         * 
                         * Print title of tabs
                         * 
                         */
                        $modulecardhtml .= html_writer::start_tag('div',['class' => "col-sm-12", 'style'=>"margin-bottom: 2rem;"]);
                        $modulecardhtml .=html_writer::tag('h2', $course->{'tabsTitle'.$str} ,['id'=>'module-title-tabs-m1','class'=>'tabs-title']);
                        $modulecardhtml .= html_writer::end_tag('div');
    
                        /**
                         * 
                         * Print editor content
                         *  
                         */
                        
                        try {
                            $idCourse = (int)$course->id;
                            $nameeditor = 'editor_tabs'.$str;
                            $valueFile = $DB->get_record_sql("SELECT value FROM mdl_course_format_options  where name='$nameeditor' and courseid=$idCourse");
                            $editorcontent = '';
                            
                            $modulecardhtml .= html_writer::start_tag('div',['class' => "col-sm-6 justify-text", 'style'=>"margin-bottom: 2rem;"]);
                            // $modulecardhtml .=html_writer::tag('p', $valueFile->value,['id'=>'module-editor-m1']);
                            $modulecardhtml .= $valueFile->value;
                            $modulecardhtml .= html_writer::end_tag('div');
                                    
                        } catch (Exception $th) {
                            echo ' error en el editor de bienvenidos', $th->getMessage();
                        }
    
                        /**
                         * 
                         * Print video tabs
                         * 
                         */
                        
                        $videocontainerhtml1 .= html_writer::start_tag('div',['class' => "col-sm-6", 'style'=>"margin-bottom: 2rem;"]);
                        if(empty($course->{'tabsVideo'.$str}) || $course->{'tabsVideo'.$str} == ' '){
                            $modulevideohtml1 .= html_writer::start_tag('div', ['style'=>'display:none']);
                            $modulevideohtml1 .= html_writer::end_tag('div');
                        }
                        else{
                        $modulevideohtml1 .= html_writer::start_tag('div',['class' => 'video-tabs']);
                        if (strpos($course->{'tabsVideo'.$str}, 'youtube') !== false) {
                            $modulevideohtml1 .= html_writer::start_tag('iframe',['src'=>"https://www.youtube-nocookie.com/embed/".substr($course->{'tabsVideo'.$str},32,11)."?rel=0&showinfo=0&modestbranding=1", 'frameborder'=>'0','allow'=>'autoplay; encrypted-media','allowfullscreen'=>'true','webkitallowfullscreen'=>'true','id'=>'video-tabs-2', 'title'=>'video presentacion pestaña '.$course->$tabsname]);
                            $modulevideohtml1 .= html_writer::end_tag('iframe');
                        }else{
                            $modulevideohtml1 .= html_writer::start_tag('iframe',['src'=>"http://tumlab.local:8082/embed?m=".substr($course->{'tabsVideo'.$str},32)."", 'id'=>'video-tabs-2', 'title'=>'video presentacion pestaña '.$course->$tabsname]);
                            $modulevideohtml1 .= html_writer::end_tag('iframe');
                        }
                        $modulevideohtml1 .= html_writer::end_tag('div');
                        }
                        $videocontainerhtml1  .= $modulevideohtml1;
                        $videocontainerhtml1 .= html_writer::end_tag('div');
    
                        $modulecardhtml .= $videocontainerhtml1;
    
                        $modulecardhtml .= html_writer::end_tag('div');
    
    
                    $modulecardhtml .= html_writer::end_tag('div');

                    $modulecardhtml .= html_writer::start_tag('div',['class' => 'modules-activites mb-2']);
                    
                    // var_dump($modinfo->get_section_info_all());
                
                foreach ($modinfo->get_section_info_all() as $section => $thissection) {

                    $module = $module + 1;
                    if($section > 5){
                        break;
                    }
                    if ($section == 0) {
                        continue;
                    }
                    if ($section > $course->numsections) {
                        continue;
                    }
                    if ($course->hiddensections && !(int)$thissection->visible) {
                        continue;
                    }
                    
                    if (isset($course->{'moduletitle' . $currentdivisor}) &&
                        $count > $course->{'moduletitle' . $currentdivisor}) {
                        $currentdivisor++;
                        $count = 1;
                    }
                    if (isset($course->{'moduletitle' . $currentdivisor}) &&
                        $course->{'moduletitle' . $currentdivisor} != 0 &&
                        !isset($divisorshow[$currentdivisor])) {
                        $currentdivisorhtml = $course->{'moduletitle' . $currentdivisor};
                        $currentdivisorhtml = str_replace('[br]', '<br>', $currentdivisorhtml);
                        $currentdivisorhtml = html_writer::tag('div', $currentdivisorhtml, ['class' => 'moduletitle']);
                        
                        $divisorshow[$currentdivisor] = true;
                    }
                    $id = 'aulas_valle-button-section-' . $section;
                            
                    if (isset($course->{'moduletitle' . $currentdivisor}) &&
                        $course->{'moduletitle' . $currentdivisor} == 1) {
                        $name = (string)$course->{'moduletitle' . ($currentdivisor)};
                        $desc = (string)$course->{'modulename' . ($currentdivisor)};
        
                    } else {
                        $name = (string)$course->{'moduletitle' . ($currentdivisor)};
                        $desc = (string)$course->{'modulename' . ($currentdivisor)};
        
                    }
        
                        $modulecardhtml .= html_writer::start_tag('div', ['class' => "card aulas_valle-card-module ",'style'=>'display:flex;margin-left: 0.2rem;margin-right: 1.5rem;', 'id'=>'aulas_valle-card-module-'.$module]);
                    
                    
                        // $act = $percent[$section]->section;
                        $user = $USER->id;
                        // $the_Activities = activities_aulas_valle($course->id,$act,$user);
                        //$sec++;
                        $class = 'aulas_valle-button-section';
                        $onclick = 'M.format_aulas_valle.show(' . $section . ',' . $course->id . ')';   
            
                        if (!$thissection->available &&
                            !empty($thissection->availableinfo)) {
                            $class .= ' sectionhidden';
                        } elseif (!$thissection->uservisible || !$thissection->visible) {
                            $class .= ' sectionhidden';
                            $onclick = false;
                        }
                     
                        if ($sectionvisible == $section) {
                            $class .= ' sectionvisible';
            
                        }
                        if ($PAGE->user_is_editing()) {
                            $onclick = false;
                        }
                        
                        $modulecardhtml .= html_writer::start_tag('div', ['class' => "col-md-12 p-0 aulas_valle-module-images-dashboard", 'id' => "dashboard-aulas_valle-".$section."", 'role'=>"img", 'aria-label'=>"momento ".$section." pestaña ".$course->$tabsname]);
                        $modulecardhtml .= html_writer::start_tag('a', ['onclick' => $onclick]);
                        
                        
                        // $aulas_valle_images_modules = 'format/aulas_valle/img/empatizar.jpg';
                        // $img_aulas_valle_modules = '<img src="' . $aulas_valle_images_modules  . '" id="module-image-'.$module.'" />';
                        // $modulecardhtml .= $img_aulas_valle_modules;
                        $modulecardhtml .= html_writer::end_tag('a');
                        $modulecardhtml .= html_writer::end_tag('div');
        
                        //$module_tittle = get_string('Modulo','format_aulas_valle');
                        // $btn_ir = get_string('ir','format_aulas_valle');
                        /* inicio del texto de las cards del modulo */
                        $modulecardhtml .= html_writer::start_tag('div', ['id' => $id, 'class' => "card-body aulas_valle-card-module-body"]);
                        
        
                        $modulecardhtml .= html_writer::start_tag('div', ['onclick' => $onclick, 'class' => 'aulas_valle-btn-start-modules']);
        
                        $modulecardhtml .= html_writer::start_tag('a',['onclick' => $onclick]);
                        $modulecardhtml.= get_string('button_modules', 'format_aulas_valle');;
                        $modulecardhtml .= html_writer::tag('i', '', ['class' => 'm-2 fa fa-arrow-circle-right']);
                        $modulecardhtml .= html_writer::end_tag('a');
        
                        $modulecardhtml .= html_writer::end_tag('div');
                        
                        $modulecardhtml .= html_writer::end_tag('div');
                        $modulecardhtml .= html_writer::end_tag('div');
                        
                        $courseimage = '';
                        $currentdivisor++;
                        $count++;
                        $img++;
                        
                }
                $modulecardhtml .= html_writer::end_tag('div');
                $modulecardhtml .= html_writer::end_tag('div');

                $cardscontainerhtml  .= $modulecardhtml;
                $modulecardhtml = '';
            

                }else if($tabs == 2){
                    $cardscontainerhtml .= html_writer::start_tag('div',['class'=>'tab-pane fade ','role'=>'tabpanel', 'id'=> 'nav-'.$moduleName, 'tabindex'=>'0']);

                    $cardscontainerhtml .= html_writer::start_tag('div',['class'=>'d-flex flex-wrap']);

                    $modulecardhtml .= html_writer::start_tag('div', ['class' => "w-100 container-fluid p-0",'style'=>'', 'id'=>'']);

                $tabsEquival = 3427;
                $str =  strval($tabs+1);
                        try {
                            $courseimage = '';
                            $fs = get_file_storage();
                            $files1 = $fs->get_area_files($context->id, 'format_aulas_valle', 'images', $tabsEquival);
                            if ($files1) {  
                                foreach ($files1 as $file1) {
                                $isimage = $file1->is_valid_image();
                                    if ($isimage) {
                                        $courseimage = moodle_url::make_pluginfile_url(
                                            $file1->get_contextid(),
                                            $file1->get_component(),
                                            $file1->get_filearea(),
                                            $tabsEquival,
                                            $file1->get_filepath(),
                                            $file1->get_filename(),
                                            false
                                        );
    
                                        $modulecardhtml .=html_writer::empty_tag('img', array('src' => $courseimage,'alt'=>$course->{'alt_text'.$str},'id'=>'module-image-bienvenidos', 'class'=>'w-100'));
                                    }
                                    else{
                                        //no hacer nada
                                    }
                                }
                            }
                        } catch (Exception $th) {
                            echo ' error en la prueba de robin', $th->getMessage();
                        }

                        $modulecardhtml .= html_writer::start_tag('div',['class' => "row"]);
                        /**
                         * 
                         * Print title of tabs
                         * 
                         */
                        $modulecardhtml .= html_writer::start_tag('div',['class' => "col-sm-12", 'style'=>"margin-bottom: 2rem;"]);
                        $modulecardhtml .=html_writer::tag('h2', $course->{'tabsTitle'.$str} ,['id'=>'module-title-tabs-m1','class'=>'tabs-title']);
                        $modulecardhtml .= html_writer::end_tag('div');
    
                        /**
                         * 
                         * Print editor content
                         *  
                         */
                        
                        try {
                            $idCourse = (int)$course->id;
                            $nameeditor = 'editor_tabs'.$str;
                            $valueFile = $DB->get_record_sql("SELECT value FROM mdl_course_format_options  where name='$nameeditor' and courseid=$idCourse");
                            $editorcontent = '';
                            
                            $modulecardhtml .= html_writer::start_tag('div',['class' => "col-sm-6 justify-text", 'style'=>"margin-bottom: 2rem;"]);
                            // $modulecardhtml .=html_writer::tag('p', $valueFile->value,['id'=>'module-editor-m1']);
                            $modulecardhtml .= $valueFile->value;
                            $modulecardhtml .= html_writer::end_tag('div');
                                    
                        } catch (Exception $th) {
                            echo ' error en el editor de bienvenidos', $th->getMessage();
                        }
    
                        /**
                         * 
                         * Print video tabs
                         * 
                         */
                        
                        $videocontainerhtml2 .= html_writer::start_tag('div',['class' => "col-sm-6", 'style'=>"margin-bottom: 2rem;"]);
                        if(empty($course->{'tabsVideo'.$str}) || $course->{'tabsVideo'.$str} == ' '){
                            $modulevideohtml2 .= html_writer::start_tag('div', ['style'=>'display:none']);
                            $modulevideohtml2 .= html_writer::end_tag('div');
                        }
                        else{
                        $modulevideohtml2 .= html_writer::start_tag('div',['class' => 'video-tabs']);
                        if (strpos($course->{'tabsVideo'.$str}, 'youtube') !== false) {
                            $modulevideohtml2 .= html_writer::start_tag('iframe',['src'=>"https://www.youtube-nocookie.com/embed/".substr($course->{'tabsVideo'.$str},32,11)."?rel=0&showinfo=0&modestbranding=1", 'frameborder'=>'0','allow'=>'autoplay; encrypted-media','allowfullscreen'=>'true','webkitallowfullscreen'=>'true','id'=>'video-tabs-3', 'title'=>'video presentacion pestaña '.$course->$tabsname]);
                            $modulevideohtml2 .= html_writer::end_tag('iframe');
                        }else{
                            $modulevideohtml2 .= html_writer::start_tag('iframe',['src'=>"http://tumlab.local:8082/embed?m=".substr($course->{'tabsVideo'.$str},32)."", 'id'=>'video-tabs-3', 'title'=>'video presentacion pestaña '.$course->$tabsname]);
                            $modulevideohtml2 .= html_writer::end_tag('iframe');
                        }
                        $modulevideohtml2 .= html_writer::end_tag('div');
                        }
                        $videocontainerhtml2  .= $modulevideohtml2;
                        $videocontainerhtml2 .= html_writer::end_tag('div');
    
                        $modulecardhtml .= $videocontainerhtml2;
    
                        $modulecardhtml .= html_writer::end_tag('div');
    
    
                    $modulecardhtml .= html_writer::end_tag('div');

                    $modulecardhtml .= html_writer::start_tag('div',['class' => 'modules-activites mb-2']);

                    
                
                foreach ($modinfo->get_section_info_all() as $section => $thissection) {

                    $module = $module + 1;

                    
                    if($section > 10){
                        break;
                    }

                    if ($section <= 5 ) {
                        continue;
                    }
                    if ($section > $course->numsections) {
                        continue;
                    }
                    if ($course->hiddensections && !(int)$thissection->visible) {
                        continue;
                    }
                    if (isset($course->{'moduletitle' . $currentdivisor}) &&
                        $count > $course->{'moduletitle' . $currentdivisor}) {
                        $currentdivisor++;
                        $count = 1;
                    }
                    if (isset($course->{'moduletitle' . $currentdivisor}) &&
                        $course->{'moduletitle' . $currentdivisor} != 0 &&
                        !isset($divisorshow[$currentdivisor])) {
                        $currentdivisorhtml = $course->{'moduletitle' . $currentdivisor};
                        $currentdivisorhtml = str_replace('[br]', '<br>', $currentdivisorhtml);
                        $currentdivisorhtml = html_writer::tag('div', $currentdivisorhtml, ['class' => 'moduletitle']);
                        
                        $divisorshow[$currentdivisor] = true;
                    }
                    $id = 'aulas_valle-button-section-' . $section;
                            
                    if (isset($course->{'moduletitle' . $currentdivisor}) &&
                        $course->{'moduletitle' . $currentdivisor} == 1) {
                        $name = (string)$course->{'moduletitle' . ($currentdivisor)};
                        $desc = (string)$course->{'modulename' . ($currentdivisor)};
        
                    } else {
                        $name = (string)$course->{'moduletitle' . ($currentdivisor)};
                        $desc = (string)$course->{'modulename' . ($currentdivisor)};
        
                    }

        
                        $modulecardhtml .= html_writer::start_tag('div', ['class' => "card aulas_valle-card-module   col-md-3 ",'style'=>'display:flex;margin-left: 0.2rem;margin-right: 1.5rem;', 'id'=>'aulas_valle-card-module-'.$module]);
                    
                    
                        // $act = $percent[$section]->section;
                        $user = $USER->id;
                        // $the_Activities = activities_aulas_valle($course->id,$act,$user);
                        //$sec++;
                        $class = 'aulas_valle-button-section';
                        $onclick = 'M.format_aulas_valle.show(' . $section . ',' . $course->id . ')';   
            
                        if (!$thissection->available &&
                            !empty($thissection->availableinfo)) {
                            $class .= ' sectionhidden';
                        } elseif (!$thissection->uservisible || !$thissection->visible) {
                            $class .= ' sectionhidden';
                            $onclick = false;
                        }
                     
                        if ($sectionvisible == $section) {
                            $class .= ' sectionvisible';
            
                        }
                        if ($PAGE->user_is_editing()) {
                            $onclick = false;
                        }
                        
                        $modulecardhtml .= html_writer::start_tag('div', ['class' => "col-md-12 p-0 aulas_valle-module-images-dashboard", 'id' => "dashboard-aulas_valle-".$section."",'role'=>"img", 'aria-label'=>"momento ".$section." pestaña ".$course->$tabsname]);
                        $modulecardhtml .= html_writer::start_tag('a', ['onclick' => $onclick]);
                        // $aulas_valle_images_modules = 'format/aulas_valle/img/M'.$module.'.png';
                        // $img_aulas_valle_modules = '<img src="' . $aulas_valle_images_modules  . '" id="module-image-'.$module.'" />';
                        // $modulecardhtml .= $img_aulas_valle_modules;
                        $modulecardhtml .= html_writer::end_tag('a');
                        $modulecardhtml .= html_writer::end_tag('div');
        
                        //$module_tittle = get_string('Modulo','format_aulas_valle');
                        // $btn_ir = get_string('ir','format_aulas_valle');
                        /* inicio del texto de las cards del modulo */
                        $modulecardhtml .= html_writer::start_tag('div', ['id' => $id, 'class' => "card-body aulas_valle-card-module-body"]);
                        $cant_char_name = strlen($name);
                        if($cant_char_name > 30){
                            $modulecardhtml .= html_writer::start_tag('a', ['onclick' => $onclick]);
                            // $modulecardhtml .= html_writer::tag('h5',substr($name, 0, 30).'...',['class' => "card-title_aulas_valle"]);
                            $modulecardhtml .= html_writer::end_tag('a');
                        }
                        else{
                            $modulecardhtml .= html_writer::start_tag('a', ['onclick' => $onclick]);
                            // $modulecardhtml .= html_writer::tag('h5',$name,['class' => "card-title_aulas_valle"]);
                            $modulecardhtml .= html_writer::end_tag('a');
                        }
                        
                        $cant_char =strlen($desc);
                        if($cant_char > 100){
                            $modulecardhtml .= html_writer::tag('p',substr($desc, 0, 100).'...',['class' => "card-text_aulas_valle"]);
                        }
                        else{
                            $modulecardhtml .= html_writer::tag('p',$desc,['class' => "card-text_aulas_valle"]);
                        }
        
                        $modulecardhtml .= html_writer::start_tag('div', ['onclick' => $onclick, 'class' => 'aulas_valle-btn-start-modules']);
        
                        $modulecardhtml .= html_writer::start_tag('a',['onclick' => $onclick]);
                        $modulecardhtml.= get_string('button_modules', 'format_aulas_valle');;
                        $modulecardhtml .= html_writer::tag('i', '', ['class' => 'm-2 fa fa-arrow-circle-right']);
                        $modulecardhtml .= html_writer::end_tag('a');
        
                        $modulecardhtml .= html_writer::end_tag('div');
                        // if(!is_String($the_Activities)){
                        //     $modulecardhtml .= html_writer::start_tag('div',['class' => "progress",'style'=>"border-radius:.25rem;"] );
                        //     if($the_Activities == 0){
                        //     $modulecardhtml .= html_writer::start_tag('div',['class'=>"progress-bar progress-bar-striped bg-success",'style'=>"width:100%;background-color: #e9ecef !important;color:#70787D"]);
                        //     }
                        //     else{
                        //     $modulecardhtml .= html_writer::start_tag('div',['class'=>"progress-bar  bg-success-bar",'style'=>"width:".$the_Activities."%;"]);
                        //     }
                        //     $modulecardhtml .= html_writer::end_tag('div');
                        //     $modulecardhtml .= html_writer::end_tag('div');
                        //     $modulecardhtml .= html_writer::tag('p',$the_Activities.'% '.get_string('completado','format_aulas_valle'),['class'=>"progress-bar-p"]);
                        //     }
                        $modulecardhtml .= html_writer::end_tag('div');
                        $modulecardhtml .= html_writer::end_tag('div');

                        $courseimage = '';
                        $currentdivisor++;
                        $count++;
                        $img++;
                        
                }
                $modulecardhtml .= html_writer::end_tag('div');
                $modulecardhtml .= html_writer::end_tag('div');

                $cardscontainerhtml  .= $modulecardhtml;

                $modulecardhtml = '';
                }else if($tabs == 3){
                
                $cardscontainerhtml .= html_writer::start_tag('div',['class'=>'tab-pane fade ','role'=>'tabpanel', 'id'=> 'nav-'.$moduleName, 'tabindex'=>'0']);

                $cardscontainerhtml .= html_writer::start_tag('div',['class'=>'d-flex flex-wrap']);

                $modulecardhtml .= html_writer::start_tag('div', ['class' => "w-100 container-fluid p-0",'style'=>'', 'id'=>'']);

            $tabsEquival = 3428;
            $str =  strval($tabs+1);
                    try {
                        $courseimage = '';
                        $fs = get_file_storage();
                        $files1 = $fs->get_area_files($context->id, 'format_aulas_valle', 'images', $tabsEquival);
                        if ($files1) {  
                            foreach ($files1 as $file1) {
                            $isimage = $file1->is_valid_image();
                                if ($isimage) {
                                    $courseimage = moodle_url::make_pluginfile_url(
                                        $file1->get_contextid(),
                                        $file1->get_component(),
                                        $file1->get_filearea(),
                                        $tabsEquival,
                                        $file1->get_filepath(),
                                        $file1->get_filename(),
                                        false
                                    );

                                    $modulecardhtml .=html_writer::empty_tag('img', array('src' => $courseimage,'alt'=>$course->{'alt_text'.$str},'id'=>'module-image-bienvenidos', 'class'=>'w-100'));
                                }
                                else{
                                    //no hacer nada
                                }
                            }
                        }
                    } catch (Exception $th) {
                        echo ' error en la prueba de robin', $th->getMessage();
                    }

                    $modulecardhtml .= html_writer::start_tag('div',['class' => "row"]);
                    /**
                     * 
                     * Print title of tabs
                     * 
                     */
                    $modulecardhtml .= html_writer::start_tag('div',['class' => "col-sm-12", 'style'=>"margin-bottom: 2rem;"]);
                    $modulecardhtml .=html_writer::tag('h2', $course->{'tabsTitle'.$str} ,['id'=>'module-title-tabs-m1','class'=>'tabs-title']);
                    $modulecardhtml .= html_writer::end_tag('div');

                    /**
                     * 
                     * Print editor content
                     *  
                     */
                    
                    try {
                        $idCourse = (int)$course->id;
                        $nameeditor = 'editor_tabs'.$str;
                        $valueFile = $DB->get_record_sql("SELECT value FROM mdl_course_format_options  where name='$nameeditor' and courseid=$idCourse");
                        $editorcontent = '';
                        
                        $modulecardhtml .= html_writer::start_tag('div',['class' => "col-sm-6 justify-text", 'style'=>"margin-bottom: 2rem;"]);
                        // $modulecardhtml .=html_writer::tag('p', $valueFile->value,['id'=>'module-editor-m1']);
                        $modulecardhtml .= $valueFile->value;
                        $modulecardhtml .= html_writer::end_tag('div');
                                
                    } catch (Exception $th) {
                        echo ' error en el editor de bienvenidos', $th->getMessage();
                    }

                    /**
                     * 
                     * Print video tabs
                     * 
                     */
                    
                    $videocontainerhtml3 .= html_writer::start_tag('div',['class' => "col-sm-6", 'style'=>"margin-bottom: 2rem;"]);
                    if(empty($course->{'tabsVideo'.$str}) || $course->{'tabsVideo'.$str} == ' '){
                        $modulevideohtml3 .= html_writer::start_tag('div', ['style'=>'display:none']);
                        $modulevideohtml3 .= html_writer::end_tag('div');
                    }
                    else{
                    $modulevideohtml3 .= html_writer::start_tag('div',['class' => 'video-tabs']);
                    if (strpos($course->{'tabsVideo'.$str}, 'youtube') !== false) {
                        $modulevideohtml3 .= html_writer::start_tag('iframe',['src'=>"https://www.youtube-nocookie.com/embed/".substr($course->{'tabsVideo'.$str},32,11)."?rel=0&showinfo=0&modestbranding=1", 'frameborder'=>'0','allow'=>'autoplay; encrypted-media','allowfullscreen'=>'true','webkitallowfullscreen'=>'true','id'=>'video-tabs-4', 'title'=>'video presentacion pestaña '.$course->$tabsname]);
                        $modulevideohtml3 .= html_writer::end_tag('iframe');
                    }else{
                        $modulevideohtml3 .= html_writer::start_tag('iframe',['src'=>"http://tumlab.local:8082/embed?m=".substr($course->{'tabsVideo'.$str},32)."", 'id'=>'video-tabs-4', 'title'=>'video presentacion pestaña '.$course->$tabsname]);
                        $modulevideohtml3 .= html_writer::end_tag('iframe');
                    }
                    $modulevideohtml3 .= html_writer::end_tag('div');
                    }
                    $videocontainerhtml3  .= $modulevideohtml3;
                    $videocontainerhtml3 .= html_writer::end_tag('div');

                    $modulecardhtml .= $videocontainerhtml3;

                    $modulecardhtml .= html_writer::end_tag('div');


                $modulecardhtml .= html_writer::end_tag('div');

                $modulecardhtml .= html_writer::start_tag('div',['class' => 'modules-activites mb-2']);
            
            foreach ($modinfo->get_section_info_all() as $section => $thissection) {

                $module = $module + 1;
                if($section > 15){
                    break;
                }

                if ($section <= 10) {
                    continue;
                }
                if ($section > $course->numsections) {
                    continue;
                }
                if ($course->hiddensections && !(int)$thissection->visible) {
                    continue;
                }
                if (isset($course->{'moduletitle' . $currentdivisor}) &&
                    $count > $course->{'moduletitle' . $currentdivisor}) {
                    $currentdivisor++;
                    $count = 1;
                }
                if (isset($course->{'moduletitle' . $currentdivisor}) &&
                    $course->{'moduletitle' . $currentdivisor} != 0 &&
                    !isset($divisorshow[$currentdivisor])) {
                    $currentdivisorhtml = $course->{'moduletitle' . $currentdivisor};
                    $currentdivisorhtml = str_replace('[br]', '<br>', $currentdivisorhtml);
                    $currentdivisorhtml = html_writer::tag('div', $currentdivisorhtml, ['class' => 'moduletitle']);
                    
                    $divisorshow[$currentdivisor] = true;
                }
                $id = 'aulas_valle-button-section-' . $section;
                        
                if (isset($course->{'moduletitle' . $currentdivisor}) &&
                    $course->{'moduletitle' . $currentdivisor} == 1) {
                    $name = (string)$course->{'moduletitle' . ($currentdivisor)};
                    $desc = (string)$course->{'modulename' . ($currentdivisor)};
    
                } else {
                    $name = (string)$course->{'moduletitle' . ($currentdivisor)};
                    $desc = (string)$course->{'modulename' . ($currentdivisor)};
    
                }

    
                    $modulecardhtml .= html_writer::start_tag('div', ['class' => "card aulas_valle-card-module   col-md-3 ",'style'=>'display:flex;margin-left: 0.2rem;margin-right: 1.5rem;', 'id'=>'aulas_valle-card-module-'.$module]);
                
                
                    // $act = $percent[$section]->section;
                    $user = $USER->id;
                    // $the_Activities = activities_aulas_valle($course->id,$act,$user);
                    //$sec++;
                    $class = 'aulas_valle-button-section';
                    $onclick = 'M.format_aulas_valle.show(' . $section . ',' . $course->id . ')';   
        
                    if (!$thissection->available &&
                        !empty($thissection->availableinfo)) {
                        $class .= ' sectionhidden';
                    } elseif (!$thissection->uservisible || !$thissection->visible) {
                        $class .= ' sectionhidden';
                        $onclick = false;
                    }
                 
                    if ($sectionvisible == $section) {
                        $class .= ' sectionvisible';
        
                    }
                    if ($PAGE->user_is_editing()) {
                        $onclick = false;
                    }
                    
                    $modulecardhtml .= html_writer::start_tag('div', ['class' => "col-md-12 p-0 aulas_valle-module-images-dashboard", 'id' => "dashboard-aulas_valle-".$section."", 'role'=>"img", 'aria-label'=>"momento ".$section." pestaña ".$course->$tabsname]);
                    $modulecardhtml .= html_writer::start_tag('a', ['onclick' => $onclick]);
                    // $aulas_valle_images_modules = 'format/aulas_valle/img/M'.$module.'.png';
                    // $img_aulas_valle_modules = '<img src="' . $aulas_valle_images_modules  . '" id="module-image-'.$module.'" />';
                    // $modulecardhtml .= $img_aulas_valle_modules;
                    $modulecardhtml .= html_writer::end_tag('a');
                    $modulecardhtml .= html_writer::end_tag('div');
    
                    //$module_tittle = get_string('Modulo','format_aulas_valle');
                    // $btn_ir = get_string('ir','format_aulas_valle');
                    /* inicio del texto de las cards del modulo */
                    $modulecardhtml .= html_writer::start_tag('div', ['id' => $id, 'class' => "card-body aulas_valle-card-module-body"]);
                    $cant_char_name = strlen($name);
                    if($cant_char_name > 30){
                        $modulecardhtml .= html_writer::start_tag('a', ['onclick' => $onclick]);
                        // $modulecardhtml .= html_writer::tag('h5',substr($name, 0, 30).'...',['class' => "card-title_aulas_valle"]);
                        $modulecardhtml .= html_writer::end_tag('a');
                    }
                    else{
                        $modulecardhtml .= html_writer::start_tag('a', ['onclick' => $onclick]);
                        // $modulecardhtml .= html_writer::tag('h5',$name,['class' => "card-title_aulas_valle"]);
                        $modulecardhtml .= html_writer::end_tag('a');
                    }
                    
                    $cant_char =strlen($desc);
                    if($cant_char > 100){
                        $modulecardhtml .= html_writer::tag('p',substr($desc, 0, 100).'...',['class' => "card-text_aulas_valle"]);
                    }
                    else{
                        $modulecardhtml .= html_writer::tag('p',$desc,['class' => "card-text_aulas_valle"]);
                    }
    
                    $modulecardhtml .= html_writer::start_tag('div', ['onclick' => $onclick, 'class' => 'aulas_valle-btn-start-modules']);
    
                    $modulecardhtml .= html_writer::start_tag('a',['onclick' => $onclick]);
                    $modulecardhtml.= get_string('button_modules', 'format_aulas_valle');;
                    $modulecardhtml .= html_writer::tag('i', '', ['class' => 'm-2 fa fa-arrow-circle-right']);
                    $modulecardhtml .= html_writer::end_tag('a');
    
                    $modulecardhtml .= html_writer::end_tag('div');
                    // if(!is_String($the_Activities)){
                    //     $modulecardhtml .= html_writer::start_tag('div',['class' => "progress",'style'=>"border-radius:.25rem;"] );
                    //     if($the_Activities == 0){
                    //     $modulecardhtml .= html_writer::start_tag('div',['class'=>"progress-bar progress-bar-striped bg-success",'style'=>"width:100%;background-color: #e9ecef !important;color:#70787D"]);
                    //     }
                    //     else{
                    //     $modulecardhtml .= html_writer::start_tag('div',['class'=>"progress-bar  bg-success-bar",'style'=>"width:".$the_Activities."%;"]);
                    //     }
                    //     $modulecardhtml .= html_writer::end_tag('div');
                    //     $modulecardhtml .= html_writer::end_tag('div');
                    //     $modulecardhtml .= html_writer::tag('p',$the_Activities.'% '.get_string('completado','format_aulas_valle'),['class'=>"progress-bar-p"]);
                    //     }
                    $modulecardhtml .= html_writer::end_tag('div');
                    $modulecardhtml .= html_writer::end_tag('div');

                    $courseimage = '';
                    $currentdivisor++;
                    $count++;
                    $img++;
                    
            }
            $modulecardhtml .= html_writer::end_tag('div');
            $modulecardhtml .= html_writer::end_tag('div');

            $cardscontainerhtml  .= $modulecardhtml;

            $modulecardhtml = '';
            }else if($tabs == 4){
            
                
            $cardscontainerhtml .= html_writer::start_tag('div',['class'=>'tab-pane fade ','role'=>'tabpanel', 'id'=> 'nav-'.$moduleName, 'tabindex'=>'0']);

            $cardscontainerhtml .= html_writer::start_tag('div',['class'=>'d-flex flex-wrap']);

            $modulecardhtml .= html_writer::start_tag('div', ['class' => "w-100 container-fluid p-0",'style'=>'', 'id'=>'']);

        $tabsEquival = 3429;
        $str =  strval($tabs+1);
                try {
                    $courseimage = '';
                    $fs = get_file_storage();
                    $files1 = $fs->get_area_files($context->id, 'format_aulas_valle', 'images', $tabsEquival);
                    if ($files1) {  
                        foreach ($files1 as $file1) {
                        $isimage = $file1->is_valid_image();
                            if ($isimage) {
                                $courseimage = moodle_url::make_pluginfile_url(
                                    $file1->get_contextid(),
                                    $file1->get_component(),
                                    $file1->get_filearea(),
                                    $tabsEquival,
                                    $file1->get_filepath(),
                                    $file1->get_filename(),
                                    false
                                );

                                $modulecardhtml .=html_writer::empty_tag('img', array('src' => $courseimage,'alt'=>$course->{'alt_text'.$str},'id'=>'module-image-bienvenidos', 'class'=>'w-100'));
                            }
                            else{
                                //no hacer nada
                            }
                        }
                    }
                } catch (Exception $th) {
                    echo ' error en la prueba de robin', $th->getMessage();
                }

                $modulecardhtml .= html_writer::start_tag('div',['class' => "row"]);
                /**
                 * 
                 * Print title of tabs
                 * 
                 */
                $modulecardhtml .= html_writer::start_tag('div',['class' => "col-sm-12", 'style'=>"margin-bottom: 2rem;"]);
                $modulecardhtml .=html_writer::tag('h2', $course->{'tabsTitle'.$str} ,['id'=>'module-title-tabs-m1','class'=>'tabs-title']);
                $modulecardhtml .= html_writer::end_tag('div');

                /**
                 * 
                 * Print editor content
                 *  
                 */
                
                try {
                    $idCourse = (int)$course->id;
                    $nameeditor = 'editor_tabs'.$str;
                    $valueFile = $DB->get_record_sql("SELECT value FROM mdl_course_format_options  where name='$nameeditor' and courseid=$idCourse");
                    $editorcontent = '';
                    
                    $modulecardhtml .= html_writer::start_tag('div',['class' => "col-sm-12 justify-text", 'style'=>"margin-bottom: 2rem;"]);
                    // $modulecardhtml .=html_writer::tag('p', $valueFile->value,['id'=>'module-editor-m1']);
                    $modulecardhtml .= $valueFile->value;
                    $modulecardhtml .= html_writer::end_tag('div');
                            
                } catch (Exception $th) {
                    echo ' error en el editor de bienvenidos', $th->getMessage();
                }

                

            $modulecardhtml .= html_writer::end_tag('div');

            $modulecardhtml .= html_writer::start_tag('div',['class' => 'modules-activites mb-2 ']);
        
        foreach ($modinfo->get_section_info_all() as $section => $thissection) {

            $module = $module + 1;
            if($section > 20){
                break;
            }

            if ($section <= 15) {
                continue;
            }
            if ($section > $course->numsections) {
                continue;
            }
            if ($course->hiddensections && !(int)$thissection->visible) {
                continue;
            }
            if (isset($course->{'moduletitle' . $currentdivisor}) &&
                $count > $course->{'moduletitle' . $currentdivisor}) {
                $currentdivisor++;
                $count = 1;
            }
            if (isset($course->{'moduletitle' . $currentdivisor}) &&
                $course->{'moduletitle' . $currentdivisor} != 0 &&
                !isset($divisorshow[$currentdivisor])) {
                $currentdivisorhtml = $course->{'moduletitle' . $currentdivisor};
                $currentdivisorhtml = str_replace('[br]', '<br>', $currentdivisorhtml);
                $currentdivisorhtml = html_writer::tag('div', $currentdivisorhtml, ['class' => 'moduletitle']);
                
                $divisorshow[$currentdivisor] = true;
            }
            $id = 'aulas_valle-button-section-' . $section;
                    
            if (isset($course->{'moduletitle' . $currentdivisor}) &&
                $course->{'moduletitle' . $currentdivisor} == 1) {
                $name = (string)$course->{'moduletitle' . ($currentdivisor)};
                $desc = (string)$course->{'modulename' . ($currentdivisor)};

            } else {
                $name = (string)$course->{'moduletitle' . ($currentdivisor)};
                $desc = (string)$course->{'modulename' . ($currentdivisor)};

            }


                $modulecardhtml .= html_writer::start_tag('div', ['class' => "card aulas_valle-card-module   col-md-3 ",'style'=>'display:flex;margin-left: 0.2rem;margin-right: 1.5rem;', 'id'=>'aulas_valle-card-module-'.$module]);
            
            
                // $act = $percent[$section]->section;
                $user = $USER->id;
                // $the_Activities = activities_aulas_valle($course->id,$act,$user);
                //$sec++;
                $class = 'aulas_valle-button-section';
                $onclick = 'M.format_aulas_valle.show(' . $section . ',' . $course->id . ')';   
    
                if (!$thissection->available &&
                    !empty($thissection->availableinfo)) {
                    $class .= ' sectionhidden';
                } elseif (!$thissection->uservisible || !$thissection->visible) {
                    $class .= ' sectionhidden';
                    $onclick = false;
                }
             
                if ($sectionvisible == $section) {
                    $class .= ' sectionvisible';
    
                }
                if ($PAGE->user_is_editing()) {
                    $onclick = false;
                }
                
                $modulecardhtml .= html_writer::start_tag('div', ['class' => "col-md-12 p-0 aulas_valle-module-images-dashboard", 'id' => "dashboard-aulas_valle-".$section."", 'role'=>"img", 'aria-label'=>"momento ".$section." pestaña ".$course->$tabsname]);
                $modulecardhtml .= html_writer::start_tag('a', ['onclick' => $onclick]);
                // $aulas_valle_images_modules = 'format/aulas_valle/img/M'.$module.'.png';
                // $img_aulas_valle_modules = '<img src="' . $aulas_valle_images_modules  . '" id="module-image-'.$module.'" />';
                // $modulecardhtml .= $img_aulas_valle_modules;
                $modulecardhtml .= html_writer::end_tag('a');
                $modulecardhtml .= html_writer::end_tag('div');

                //$module_tittle = get_string('Modulo','format_aulas_valle');
                // $btn_ir = get_string('ir','format_aulas_valle');
                /* inicio del texto de las cards del modulo */
                $modulecardhtml .= html_writer::start_tag('div', ['id' => $id, 'class' => "card-body aulas_valle-card-module-body"]);
                $cant_char_name = strlen($name);
                if($cant_char_name > 30){
                    $modulecardhtml .= html_writer::start_tag('a', ['onclick' => $onclick]);
                    // $modulecardhtml .= html_writer::tag('h5',substr($name, 0, 30).'...',['class' => "card-title_aulas_valle"]);
                    $modulecardhtml .= html_writer::end_tag('a');
                }
                else{
                    $modulecardhtml .= html_writer::start_tag('a', ['onclick' => $onclick]);
                    // $modulecardhtml .= html_writer::tag('h5',$name,['class' => "card-title_aulas_valle"]);
                    $modulecardhtml .= html_writer::end_tag('a');
                }
                
                $cant_char =strlen($desc);
                if($cant_char > 100){
                    $modulecardhtml .= html_writer::tag('p',substr($desc, 0, 100).'...',['class' => "card-text_aulas_valle"]);
                }
                else{
                    $modulecardhtml .= html_writer::tag('p',$desc,['class' => "card-text_aulas_valle"]);
                }

                $modulecardhtml .= html_writer::start_tag('div', ['onclick' => $onclick, 'class' => 'aulas_valle-btn-start-modules']);

                $modulecardhtml .= html_writer::start_tag('a',['onclick' => $onclick]);
                $modulecardhtml.= get_string('button_modules', 'format_aulas_valle');;
                $modulecardhtml .= html_writer::tag('i', '', ['class' => 'm-2 fa fa-arrow-circle-right']);
                $modulecardhtml .= html_writer::end_tag('a');

                $modulecardhtml .= html_writer::end_tag('div');
                // if(!is_String($the_Activities)){
                //     $modulecardhtml .= html_writer::start_tag('div',['class' => "progress",'style'=>"border-radius:.25rem;"] );
                //     if($the_Activities == 0){
                //     $modulecardhtml .= html_writer::start_tag('div',['class'=>"progress-bar progress-bar-striped bg-success",'style'=>"width:100%;background-color: #e9ecef !important;color:#70787D"]);
                //     }
                //     else{
                //     $modulecardhtml .= html_writer::start_tag('div',['class'=>"progress-bar  bg-success-bar",'style'=>"width:".$the_Activities."%;"]);
                //     }
                //     $modulecardhtml .= html_writer::end_tag('div');
                //     $modulecardhtml .= html_writer::end_tag('div');
                //     $modulecardhtml .= html_writer::tag('p',$the_Activities.'% '.get_string('completado','format_aulas_valle'),['class'=>"progress-bar-p"]);
                //     }
                $modulecardhtml .= html_writer::end_tag('div');
                $modulecardhtml .= html_writer::end_tag('div');

                $courseimage = '';
                $currentdivisor++;
                $count++;
                $img++;
                
        }
        $modulecardhtml .= html_writer::end_tag('div');
        $modulecardhtml .= html_writer::end_tag('div');

        $cardscontainerhtml  .= $modulecardhtml;

        $modulecardhtml = '';
        }
            /** aqui se debe de imprimir el contenido de cada tab */
            $countabs += 5;

            /**
             * 
             */
            $cardscontainerhtml .= html_writer::end_tag('div');
            
        }
        $cardscontainerhtml .= html_writer::end_tag('div');


        
        /**
         * Se cierra la construcción del contenedor de tarjetas
         */
        $cardscontainerhtml .= html_writer::end_tag('div');
        $cardscontainerhtml .= html_writer::end_tag('div');   
        $cardscontainerhtml .= html_writer::end_tag('div');
        // $container_home .= $videocontainerhtml;
        $container_home .= $cardscontainerhtml;     
        $html .= $container_home;
        
        /**
         * Se construye la barra de navegación para regresar desde una sección incluyendo el evento para regresar de una sección
         */
        foreach ($modinfo->get_section_info_all() as $section => $thissection) {

            $modules = $modules + 1;
            if ($section == 0) {
                continue;
            }
            if ($section > $course->numsections) {
                continue;
            }
            if ($course->hiddensections && !(int)$thissection->visible) {
                continue;
            }
           
            $containerModule .= html_writer::start_tag('div',['id' => 'container-'.$modules.'','style'=>'margin-top:2em']);

            

            $containerModule .= html_writer::end_tag('div'); 

            $course_btn_back_lang = get_string('back', 'format_aulas_valle');
            $onbackclick = 'M.format_aulas_valle.back(' . $course->id . ')';
            $backnavhtml .= html_writer::start_tag('nav', ['class' => "navbar sticky-top navbar-light aulas_valle-back-navbar", 'id' => 'aulas_valle-back-nav-'.$modules]);
            $backnavhtml .= html_writer::start_tag('a',  ['class' => 'btn btn-primary btn-sm aulas_valle-back-nav', 'onclick' => $onbackclick]);
            $backnavhtml .= html_writer::tag('i', '', ['class' => 'fa fa-arrow-left']);
            $backnavhtml .= $course_btn_back_lang;
            $backnavhtml .= html_writer::end_tag('a');
            // $aulas_valle_images_activities = 'format/aulas_valle/img/BANNER-ACTIVIDAD.png';
            // $img_aulas_valle = '<img src="' . $aulas_valle_images_activities . '" id="module-image" />';
            // $backnavhtml .= $img_aulas_valle;
            /** lessons title */
            // $backnavhtml .= html_writer::start_tag('div');

            // $backnavhtml .= html_writer::tag('h5','Actividades',['class' => "mt-4 aulas_valle-title-modules",]);
            // $backnavhtml .= html_writer::tag('p','En esta sección podrás encontrar las actividades  ligados a tu módulo',['class' => "aulas_valle-subtitle-module",]);

            // $backnavhtml .= html_writer::end_tag('div');
            
            $backnavhtml .= html_writer::end_tag('nav');
            
            
            $backnavhtml .= $containerModule;

            $divisorvideos++;
            $containerModule ='';
            $count1++;
            // }
           }
           /**
         * Se cierra la construcción de los contenedores internos
         */
           $html .= $backnavhtml;
           $html = html_writer::tag('div', $html, ['id' => 'aulas_valle-container-section']);
           if ($PAGE->user_is_editing()) {
               $load = 'M.format_aulas_valle.showmodule()';
               $html .= html_writer::tag('div', get_string('editing', 'format_aulas_valle'), ['class' => 'alert alert-warning alert-block fade in']);
               
           }
        return $html;
    }

    /**
     * number_to_roman
     *
     * @param integer $number
     * @return string
     */
    protected function number_to_roman($number)
    {
        $number = intval($number);
        $return = '';
        $romanarray = [
            'M' => 1000,
            'CM' => 900,
            'D' => 500,
            'CD' => 400,
            'C' => 100,
            'XC' => 90,
            'L' => 50,
            'XL' => 40,
            'X' => 10,
            'IX' => 9,
            'V' => 5,
            'IV' => 4,
            'I' => 1
        ];
        foreach ($romanarray as $roman => $value) {
            $matches = intval($number / $value);
            $return .= str_repeat($roman, $matches);
            $number = $number % $value;
        }
        return $return;
    }

    /**
     * number_to_alphabet
     *
     * @param integer $number
     * @return string
     */
    protected function number_to_alphabet($number)
    {
        $number = $number - 1;
        $alphabet = range("A", "Z");
        if ($number <= 25) {
            return $alphabet[$number];
        } elseif ($number > 25) {
            $dividend = ($number + 1);
            $alpha = '';
            while ($dividend > 0) {
                $modulo = ($dividend - 1) % 26;
                $alpha = $alphabet[$modulo] . $alpha;
                $dividend = floor((($dividend - $modulo) / 26));
            }
            return $alpha;
        }
    }

    /**
     * start_section_list
     *
     * @return string
     */
    protected function start_section_list()
    {   
        global $PAGE;
        if ($PAGE->user_is_editing()) {
            $class_editing ='aulas_valle-editing';
            return html_writer::start_tag('ul', ['class' => 'buttons row '.$class_editing. '','id'=>'rowinit']);
        }
        return html_writer::start_tag('ul', ['class' => 'buttons row aulas_valle-no-editing','id'=>'rowinit']);
    }
    /**
     * section_header
     *
     * @param stdclass $section
     * @param stdclass $course
     * @param bool $onsectionpage
     * @param int $sectionreturn
     * @return string
     */
    protected function section_header($section, $course, $onsectionpage, $sectionreturn = null, $contenttext)
    {
        global $PAGE, $CFG;
        $o = '';
        $containerText  = '';
        $currenttext = '';
        $sectionstyle = '';
        
        if ($section->section != 0) {
            if (!$section->visible) {
                $sectionstyle = ' hidden';
            } elseif (course_get_format($course)->is_section_current($section)) {
                $sectionstyle = ' current';
            }
        }
        $o .= html_writer::start_tag('li', ['id' => 'section-'.$section->section,
        'class' => 'section main clearfix col-sm-12'.$sectionstyle,
        'role' => 'region', 'aria-label' => get_section_name($course, $section),'style'=>'display:block']);
        $o .= html_writer::tag('span', $this->section_title($section, $course), ['class' => 'hidden sectionname']);
        $leftcontent = $this->section_left_content($section, $course, $onsectionpage);
        $o .= html_writer::tag('div', $leftcontent, ['class' => 'left side']);
        $rightcontent = $this->section_right_content($section, $course, $onsectionpage);
        $o .= html_writer::tag('div', $rightcontent, ['class' => 'right side']);
        $o .= html_writer::start_tag('div', ['class' => 'content']);
        $hasnamenotsecpg = (!$onsectionpage && ($section->section != 0 || !is_null($section->name)));
        $hasnamesecpg = ($onsectionpage && ($section->section == 0 && !is_null($section->name)));
        $classes = ' accesshide';
        if ($hasnamenotsecpg || $hasnamesecpg) {
            $classes = '';
        }
        $sectionname = html_writer::tag('span', $this->section_title($section, $course));
        if ($course->showdefaultsectionname) {
            $o .= $this->output->heading($sectionname, 3, 'sectionname' . $classes);
        }       
        $o .= html_writer::start_tag('div', ['class' => 'summary','id'=>'summary','style'=>'display:none']);
        //if ((int)$section != 0) {
        if ($section->section != 0) {
            $o .= $contenttext;
        }
        $o .= $this->format_summary_text($section);
        $context = context_course::instance($course->id);
        $o .= html_writer::end_tag('div');
        $o .= $this->section_availability_message($section, has_capability('moodle/course:viewhiddensections', $context));
        return $o;
    }

    /**
     * print_multiple_section_page
     *
     * @param stdclass $course
     * @param array $sections (argument not used)
     * @param array $mods (argument not used)
     * @param array $modnames (argument not used)
     * @param array $modnamesused (argument not used)
     */
    public function print_multiple_section_page($course, $sections, $mods, $modnames, $modnamesused)
    {
        global $PAGE,$DB;
        $modinfo = get_fast_modinfo($course);
        $course = course_get_format($course)->get_course();
        $context = context_course::instance($course->id);
        $completioninfo = new completion_info($course);
        $divisorshow = false;
        $contentvideo='';
        $containervideo = '';
        $modulevideohtmlmodules = '';
        $modulevideohtmlmodules1 = '';
        $modulevideohtmlmodules2 = '';
        $modulevideohtmlmodules3 = '';
        $modulevideohtmlmodules4 = '';
        $modulevideohtmlmodules5 = '';
        $modulevideohtmlmodules6 = '';
        $modulevideohtmlmodules7 = '';
        $modulevideohtmlmodules8 = '';
        $modulevideohtmlmodules9 = '';
        $modulevideohtmlmodules10 = '';
        $modulevideohtmlmodules11 = '';
        $modulevideohtmlmodules12 = '';
        $modulevideohtmlmodules13 = '';
        $modulevideohtmlmodules14 = '';
        $modulevideohtmlmodules15 = '';
        $modulevideohtmlmodules16 = '';
        $modulevideohtmlmodules17 = '';
        $modulevideohtmlmodules18 = '';
        $modulevideohtmlmodules19 = '';
        $modulevideohtmlmodules20 = '';
        $count1 = 1;
        $count2 = 1;
        $currentdivisor1 = 1;
        $currentdivisor2 = 1;
        if (isset($_COOKIE['sectionvisible_'.$course->id])) {
            $sectionvisible = $_COOKIE['sectionvisible_'.$course->id];
        } elseif ($course->marker > 0) {
            $sectionvisible = $course->marker;
        } else {
            $sectionvisible = 1;
        }
        $htmlsection = false;
        
        foreach ($modinfo->get_section_info_all() as $section => $thissection) {

            
            $htmlsection[$section+1] = '';
            $contenttext ='';
            if ($section == 0) {
                $section0 = $thissection;
                continue;
            }
            if ($section > $course->numsections) {
                continue;
            }
            //format text
            //nombre de los modulos
            if (isset($course->{'moduletitle' . $currentdivisor1}) &&
            $count1 > $course->{'moduletitle' . $currentdivisor1}) {
            $currentdivisor1++;
            $count1 = 1;
        }
        if (isset($course->{'moduletitle' . $currentdivisor1}) &&
            $course->{'moduletitle' . $currentdivisor1} != 0 &&
            !isset($divisorshow[$currentdivisor1])) {
            $currentdivisor1html = $course->{'moduletitle' . $currentdivisor1};
            $currentdivisor1html = str_replace('[br]', '<br>', $currentdivisor1html);
            $currentdivisor1html = html_writer::tag('div', $currentdivisor1html, ['class' => 'moduletitle']);
            
            $divisorshow[$currentdivisor1] = true;
        }
    
        if (isset($course->{'moduletitle' . $currentdivisor1}) &&
            $course->{'moduletitle' . $currentdivisor1} == 1) {
            $name = (string)$course->{'moduletitle' . ($currentdivisor1-1)};
            $desc = (string)$course->{'modulename' . ($currentdivisor1-1)};

        } else {
            $name = (string)$course->{'moduletitle' . ($currentdivisor1-1)};
            $desc = (string)$course->{'modulename' . ($currentdivisor1-1)};

        }
        /**
         * 
         * Imagen interna de los modulos
         * 
         */
        $contenttext .= html_writer::start_tag('div',['class'=>'d-flex flex-wrap editing-modules']);

        $contenttext .= html_writer::start_tag('div', ['class' => "w-100 container-fluid p-0",'style'=>'', 'id'=>'']);
                /**
                 * 
                 * Imagen del modulo
                 * 
                 */
                try {
                    $courseimage = '';
                    $fs = get_file_storage();
                    $files1 = $fs->get_area_files($context->id, 'format_aulas_valle', 'images', $section);
                    if ($files1) {  
                        foreach ($files1 as $file1) {
                        $isimage = $file1->is_valid_image();
                            if ($isimage) {
                                $courseimage = moodle_url::make_pluginfile_url(
                                    $file1->get_contextid(),
                                    $file1->get_component(),
                                    $file1->get_filearea(),
                                    $section,
                                    $file1->get_filepath(),
                                    $file1->get_filename(),
                                    false
                                );

                                $contenttext .=html_writer::empty_tag('img', array('src' => $courseimage,'alt'=>$course->{'alt_module_img'.$section},'id'=>'module-image-bienvenidos', 'class'=>'w-100'));
                            }
                            else{
                                //no hacer nada
                            }
                        }
                    }
                } catch (Exception $th) {
                    echo ' error en la prueba de robin', $th->getMessage();
                }

                /**
                 * 
                 * Imagen del momento
                 * 
                 */
                $contenttext .= html_writer::start_tag('div', ['class' => "col-sm-4",'style'=>'', 'id'=>'']);
                $tabsEquivalmoment = 131513;
                try {
                    $courseimage = '';
                    $fs = get_file_storage();
                    $files1 = $fs->get_area_files($context->id, 'format_aulas_valle', 'images', $tabsEquivalmoment += $section);
                    if ($files1) {  
                        foreach ($files1 as $file1) {
                        $isimage = $file1->is_valid_image();
                            if ($isimage) {
                                $courseimage = moodle_url::make_pluginfile_url(
                                    $file1->get_contextid(),
                                    $file1->get_component(),
                                    $file1->get_filearea(),
                                    $tabsEquivalmoment,
                                    $file1->get_filepath(),
                                    $file1->get_filename(),
                                    false
                                );

                                $contenttext .=html_writer::empty_tag('img', array('src' => $courseimage,'alt'=>$course->{'alt_module_moment'.$section},'id'=>'module-image-bienvenidos', 'class'=>'w-100'));
                            }
                            else{
                                //no hacer nada
                            }
                        }
                    }
                } catch (Exception $th) {
                    echo ' error en la prueba de robin', $th->getMessage();
                }

                $contenttext .= html_writer::end_tag('div');


                $contenttext .= html_writer::start_tag('div',['class' => "row"]);

                /**
                 * 
                 * Print editor content
                 *  
                 */
                
                try {
                    $idCourse = (int)$course->id;
                    $nameeditor = 'editor_modules'.$section;
                    $valueFile = $DB->get_record_sql("SELECT value FROM mdl_course_format_options  where name='$nameeditor' and courseid=$idCourse");
                    $editorcontent = '';
                    
                    $contenttext .= html_writer::start_tag('div',['class' => "col-sm-12 justify-text", 'style'=>"margin-bottom: 2rem;"]);
                    // $contenttext .=html_writer::tag('p', $valueFile->value,['id'=>'module-editor-m1']);
                    $contenttext .= $valueFile->value;
                    $contenttext .= html_writer::end_tag('div');
                            
                } catch (Exception $th) {
                    echo ' error en el editor de bienvenidos', $th->getMessage();
                }

                /**
                 * 
                 * Print video tabs
                 * 
                 */

                // $contentvideo .= html_writer::start_tag('div',['class' => "col-sm-6", 'style'=>"margin-bottom: 2rem;"]);
                // if(empty($course->{'modulevideo'.$section}) || $course->{'modulevideo'.$section} == ' '){
                //     $containervideo .= html_writer::start_tag('div', ['style'=>'display:none']);
                //     $containervideo .= html_writer::end_tag('div');
                // }
                // else{
                // $containervideo .= html_writer::start_tag('div',['class' => 'video-tabs']);
                // $containervideo .= html_writer::start_tag('iframe',['src'=>"https://www.youtube-nocookie.com/embed/".substr($course->{'modulevideo'.$section},32,11)."?rel=0&showinfo=0&modestbranding=1", 'frameborder'=>'0','allow'=>'encrypted-media','allowfullscreen'=>'true','webkitallowfullscreen'=>'true','id'=>'video-modules'.$section, 'title'=>'video presentacion del momento ']);
                // $containervideo .= html_writer::end_tag('iframe');
                // $containervideo .= html_writer::end_tag('div');
                // }
                
                // $contentvideo  .= $containervideo; 

                // $contentvideo .= html_writer::end_tag('div');

                // $contenttext .= $contentvideo;

                // $contenttext .= html_writer::end_tag('div');


            // $contenttext .= html_writer::end_tag('div');
            $contenttext .= html_writer::end_tag('div');
            $containervideo = '';
            $contentvideo = '';

        //objetivo interno de los modulos
        // if (isset($course->{'moduleobjetive' . $currentdivisor2}) &&
        //     $count2 > $course->{'moduleobjetive' . $currentdivisor2}) {
        //     $currentdivisor2++;
        //     $count2 = 1;
        // }
        // if (isset($course->{'moduleobjetive' . $currentdivisor2}) &&
        //     $course->{'moduleobjetive' . $currentdivisor2} != 0 &&
        //     !isset($divisorshow[$currentdivisor2])) {
        //     $currentdivisor2html = $course->{'moduleobjetive' . $currentdivisor2};
        //     $currentdivisor2html = str_replace('[br]', '<br>', $currentdivisor2html);
        //     $currentdivisor2html = html_writer::tag('div', $currentdivisor2html, ['class' => 'moduleobjetive']);
            
        //     $divisorshow[$currentdivisor2] = true;
        // }
        // if (isset($course->{'moduleobjetive' . $currentdivisor2}) &&
        //     $course->{'moduleobjetive' . $currentdivisor2} == 1) {
        //     $nameobj = (string)$course->{'moduleobjetive' . ($currentdivisor2-1)};
        // } else {
        //     $nameobj = (string)$course->{'moduleobjetive' . ($currentdivisor2-1)};
        // }
        // $course_Desempeno_lang = get_string('desempeno', 'format_aulas_valle');
        // $contenttext .= html_writer::start_tag('div',['style'=> 'margin-top:2em']);
        // $contenttext .= html_writer::tag('h2',$name,['class'=>'featurette-heading']);
        // $contenttext .= html_writer::tag('h3',$desc,['class'=>'featurette-heading']);
        // $contenttext .= html_writer::tag('h5',$course_Desempeno_lang);   
        // $contenttext .= html_writer::tag('p',$nameobj,['class'=>'lead']);
        // $contenttext .= html_writer::end_tag('div');
        
        $count1++;
        $count2++;
            /* if is not editing verify the rules to display the sections */
            if (!$PAGE->user_is_editing()) {
                if ($course->hiddensections && !(int)$thissection->visible) {
                    continue;
                }
                if (!$thissection->available && !empty($thissection->availableinfo)) {
                    $htmlsection[$section] .= $this->section_header($thissection, $course, false, 0, $contenttext);
                    continue;
                }
                if (!$thissection->uservisible || !$thissection->visible) {
                    $htmlsection[$section] .= $this->section_hidden($section, $course->id);
                    continue;
                }
            }
            
            $htmlsection[$section] .= $this->section_header($thissection, $course, false, 0, $contenttext);
            if ($thissection->uservisible) {
                $htmlsection[$section] .= $this->courserenderer->course_section_cm_list($course, $thissection, 0);
                $htmlsection[$section] .= $this->courserenderer->course_section_add_cm_control($course, $section, 0);
            }
            $htmlsection[$section] .= $this->section_footer();
        }
       // echo "<p id='charge'>".get_string('cargando', 'format_aulas_valle')."</p>";
        echo "<div id='charge' class='lds-roller'><div></div><div></div><div></div><div></div><div></div><div></div><div></div><div></div></div>";
        
        if ($section0->summary || !empty($modinfo->sections[0]) || !$PAGE->user_is_editing()) {
            $htmlsection0 = $this->section_header($section0, $course, false, 0, $contenttext);
            $htmlsection0 .= $this->courserenderer->course_section_cm_list($course, $section0, 0);
            $htmlsection0 .= $this->courserenderer->course_section_add_cm_control($course, 0, 0);
            $htmlsection0 .= $this->section_footer();
        }
        echo $completioninfo->display_help_icon();
        echo $this->output->heading($this->page_title(), 2, 'accesshide');
        echo $this->course_activity_clipboard($course, 0);        
        echo $this->start_section_list();  
        echo $this->get_button_section($course, 0);
        echo html_writer::tag('span', $htmlsection0, ['class' => 'above','id'=>'above', 'style'=>'width:100%']);
        
        

        foreach ($htmlsection as $current) {
            echo $current;
        }

        if ($PAGE->user_is_editing() and has_capability('moodle/course:update', $context)) {

            echo html_writer::tag('style', '#rowinit { display: block !important; }');            
            echo html_writer::tag('style', '.course-content ul.buttons #section-'.$sectionvisible.' { display: block;flex: 0 0 100%;max-width: 100%;  }');
            echo html_writer::tag('style', '.course-content ul.buttons li.section.main { max-width: 100%; }');
            echo html_writer::tag('style', '#charge { display: none; }');
            echo html_writer::tag('style', '#summary { display: block !important; }');
            foreach ($modinfo->get_section_info_all() as $section => $thissection) {
                if ($section <= $course->numsections or empty($modinfo->sections[$section])) {
                    continue;
                }
                echo $this->stealth_section_header($section);
                echo $this->courserenderer->course_section_cm_list($course, $thissection, 0);
                echo $this->stealth_section_footer();
            }
            echo $this->end_section_list();
            echo html_writer::start_tag('div', ['id' => 'changenumsections', 'class' => 'mdl-right']);
            $straddsection = get_string('increasesections', 'moodle');
            $url = new moodle_url('/course/changenumsections.php', ['courseid' => $course->id,
                'increase' => true, 'sesskey' => sesskey()]);
            $icon = $this->output->pix_icon('t/switch_plus', $straddsection);
            echo html_writer::link($url, $icon.get_accesshide($straddsection), ['class' => 'increase-sections']);
            if ($course->numsections > 0) {
                $strremovesection = get_string('reducesections', 'moodle');
                $url = new moodle_url('/course/changenumsections.php', ['courseid' => $course->id,
                    'increase' => false, 'sesskey' => sesskey()]);
                $icon = $this->output->pix_icon('t/switch_minus', $strremovesection);
                echo html_writer::link(
                    $url,
                    $icon.get_accesshide($strremovesection),
                ['class' => 'reduce-sections']
                );
            }
            echo html_writer::end_tag('div');
        } else {
            echo $this->end_section_list();
        }
        echo html_writer::tag('style', '.course-content ul.buttons #section-'.$sectionvisible.' { display: none; }');
        echo html_writer::tag('style', '#completionprogressid { display: none; }');
        echo html_writer::tag('style', '#rowinit { display: none; }');

        if (!$PAGE->user_is_editing()) {
            $PAGE->requires->js_init_call('M.format_aulas_valle.init', [$course->numsections,$course->id]);
            echo html_writer::tag('style', '#summary { display: block !important; }');

        }
    }
  


}